#!/usr/bin/python3

import amulet
import unittest

from graylogapi import GraylogAPI


ADMIN_PASSWORD = 'admin'
ADMIN_PASSWORD_HASH = '8c6976e5b5410415bde908bd4dee15dfb167a9c873fc4bb8a81f6f2ab448a918'
CLUSTER_NAME = 'amulet'
DEFAULT_WEB_PORT = '9000'


class TestCharm(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        cls.d = amulet.Deployment(series='xenial')

        cls.d.add('graylog')
        # TODO add in clustered graylog when support for it exists
        cls.d.configure('graylog', {
            'admin_password': ADMIN_PASSWORD,
            'elasticsearch_cluster_name': CLUSTER_NAME,
        })

        cls.d.add('mongodb', 'cs:mongodb', units=3)
        cls.d.configure('mongodb', {
            'replicaset': CLUSTER_NAME,
        })
        cls.d.relate('graylog:mongodb', 'mongodb:database')

        cls.d.add('elasticsearch', 'cs:~ivoks/elasticsearch', units=3)
        cls.d.configure('elasticsearch', {
            'apt-repository': 'deb https://packages.elastic.co/elasticsearch/2.x/debian stable main',
            'cluster-name': CLUSTER_NAME,
            'firewall_enabled': 'false',
        })
        cls.d.relate('graylog:elasticsearch', 'elasticsearch:client')

        cls.d.setup(timeout=900)
        cls.d.sentry.wait()

        cls.graylog = cls.d.sentry['graylog'][0]

        cls.config = cls.graylog.file_contents('/var/snap/graylog/common/server.conf')
        api_url = "http://{}:9001/api".format(cls.graylog.info['public-address'])
        cls.api = GraylogAPI(api_url, 'admin', ADMIN_PASSWORD)

    def test_elasticsearch_active(self):
        resp = self.api.get('/system/indexer/cluster/health')
        self.assertTrue(resp.json()['status'] == 'green')
        for elasticsearch in self.d.sentry['elasticsearch']:
            ip = elasticsearch.relation('client', 'graylog:elasticsearch')['private-address']
            self.assertTrue(ip in self.config)

    def test_mongodb_active(self):
        resp = self.api.get('/cluster')
        self.assertTrue(list(resp.json().values())[0]['is_processing'])
        for mongodb in self.d.sentry['mongodb']:
            ip = mongodb.relation('database', 'graylog:mongodb')['private-address']
            self.assertTrue(ip in self.config)


if __name__ == "__main__":
    unittest.main()
