import os
import sys
import tempfile
import unittest

sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

from reactive.graylog import set_conf


initial_conf = u"""#key1 = value1
key2 = value2
key2=value3
### key3   =  value 4
key4 = value5"""

update1_conf = u"""#key1 = value1
key2 = value2
key2=value3
### key3   =  value 4
key4 = valueUpdated"""

commented1_conf = u"""key1 = value1
key2 = value2
key2=value3
### key3   =  value 4
key4 = value5"""

commented2_conf = u"""key1 = value1
key2 = value2
key2=value3
key3 = value4
key4 = value5"""

duplicate1_conf = u"""#key1 = value1
key2 = value6
#key2=value3
### key3   =  value 4
key4 = value5"""


class TestSetConf(unittest.TestCase):

    def setUp(self):
        temp_file = tempfile.NamedTemporaryFile(delete=False)
        temp_file.write(initial_conf.encode())
        temp_file.close()
        self.conf_file = temp_file.name

    def tearDown(self):
        os.remove(self.conf_file)

    def conf_equals(self, want):
        with open(self.conf_file, 'r') as conf:
            got = conf.read()
            if got == want:
                return True
            print('{}\n != \n{}'.format(got, want))
        return False

    def test_update(self):
        set_conf('key4', 'value5', self.conf_file)
        self.assertTrue(self.conf_equals(initial_conf))

        set_conf('key4', 'valueUpdated', self.conf_file)
        self.assertTrue(self.conf_equals(update1_conf))

    def test_set_commented(self):
        set_conf('key1', 'value1', self.conf_file)
        self.assertTrue(self.conf_equals(commented1_conf))

        set_conf('key3', 'value4', self.conf_file)
        self.assertTrue(self.conf_equals(commented2_conf))

    def test_handle_duplicates(self):
        set_conf('key2', 'value6', self.conf_file)
        self.assertTrue(self.conf_equals(duplicate1_conf))

    def test_no_changed(self):
        self.assertFalse(set_conf('key2', 'value2', self.conf_file))

    def test_changed(self):
        self.assertTrue(set_conf('key2', 'some-new-value', self.conf_file))
